from django.shortcuts import render, get_object_or_404
from django.http import HttpResponse, Http404
from django.views.decorators.http import require_safe

from pgp import models

@require_safe
def policy(request, domain=None):
    if domain is None:
        domain = request.get_host().rsplit(":", 1)[0]
    response =  HttpResponse(f"# WKD policy file for {domain}",
                             content_type="text/plain")
    response["Access-Control-Allow-Origin"] = "*"
    response["Access-Control-Allow-Methods"] = "GET, OPTIONS, HEAD"
    return response

@require_safe
def lookup(request, zbase, domain=None):
    if domain is None:
        domain = request.get_host().rsplit(":", 1)[0]

    publickey = get_object_or_404(models.PublicKey,
                                  wkdid=zbase,
                                  email__endswith=f"@{domain}")
    if not request.user.has_perm("pgp.view_publickey", publickey):
        raise Http404()

    if publickey._decode():
        encoded = publickey.decoded.ascii_unarmor(str(publickey.decoded))
        response = HttpResponse(bytes(encoded["body"]),
                                content_type="application/octet-stream")
    else:
        response = HttpResponse(b"",
                                content_type="application/octet-stream")

    response["Access-Control-Allow-Origin"] = "*"
    response["Access-Control-Allow-Methods"] = "GET, OPTIONS, HEAD"
    return response
